# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
⬆️ Upgrade to lndb-schema-core v0.2.0 | [2](https://github.com/laminlabs/lndb-hub/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.2.0
🚚 Move the code from lamindb here | [1](https://github.com/laminlabs/lndb-hub/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.1.0
